**11. Publications and Relevant Studies**
==========================================

**Recent papers that have used PowNet:**

-  Koh, R., Galelli, S. (2024) `Evaluating Streamflow Forecasts in
   Hydro-Dominated Power Systems--When and Why They
   Matter <https://agupubs.onlinelibrary.wiley.com/doi/full/10.1029/2023WR035825>`_. Water
   Resources Research, 60, e2023WR035825.

..

-  Galelli, S., Dang, T.D., Ng, J.Y., Chowdhury, A.F.M.K., Arias, M.E.
   (2022) `Curbing hydrological alterations in the Mekong–limits and
   opportunities of dam
   re-operation <https://www.nature.com/articles/s41893-022-00971-z>`_. Nature
   Sustainability, 5, 1058–1069.

..

-  Koh, R., Kern, J., Galelli, S. (2022) `Hard-coupling water and power
   system models increases the complementarity of renewable energy
   sources <https://www.sciencedirect.com/science/article/abs/pii/S0306261922007255>`_. Applied
   Energy, 321, 119386.

..

-  Chowdhury, A.K., Dang, T.D., Nguyen, H.T., Koh, R., and Galelli, S.,
   (2021). `The Greater Mekong's climate-water-energy nexus: how
   ENSO-triggered regional droughts affect power supply and CO2
   emissions <https://doi.org/10.1029/2020EF001814>`_. Earth’s Future,
   9, e2020EF001814.

..

-  Chowdhury, A.K., Dang, T.D., Bagchi, A., and Galelli, S.,
   (2020). `Expected benefits of Laos' hydropower development curbed by
   hydro-climatic variability and limited transmission
   capacity—opportunities to
   reform <https://doi.org/10.1061/(ASCE)WR.1943-5452.0001279>`_. Journal
   of Water Resources Planning and Management, 146(10), 05020019.
